IPMI password entry cleanup

Whenever user is removed from the system, password map in IPMI
database has to be cleaned up. Similarly password entry must
be updated when user rename happens. This commit add's API
changes for the same

Change-Id: I304c721b31fc7fbad019c85d8ca2ecc60ca398d8
Signed-off-by: Richard Marian Thomaiyar <richard.marian.thomaiyar@linux.intel.com>
diff --git a/user_channel/passwd_mgr.hpp b/user_channel/passwd_mgr.hpp
index e5625bc..a444522 100644
--- a/user_channel/passwd_mgr.hpp
+++ b/user_channel/passwd_mgr.hpp
@@ -46,13 +46,17 @@
      */
     std::string getPasswdByUserName(const std::string& userName);
 
-    /** @brief Clear username and password entry for the specified user
+    /** @brief Update / clear  username and password entry for the specified
+     * user
      *
-     *  @param[in] userName - username
+     *  @param[in] userName - user name that has to be renamed / deleted
+     *  @param[in] newUserName - new user name. If empty, userName will be
+     *   deleted.
      *
      * @return error response
      */
-    int clearUserEntry(const std::string& userName);
+    int updateUserEntry(const std::string& userName,
+                        const std::string& newUserName);
 
   private:
     using UserName = std::string;
@@ -81,11 +85,14 @@
     /** @brief  Updates special password file by clearing the password entry
      *  for the user specified.
      *
      *  @param[in] userName - user name entry that has to be removed.
      *
      * @return error response
      */
-    int updatePasswdSpecialFile(const std::string& userName);
+    int updatePasswdSpecialFile(const std::string& userName,
+                                const std::string& newUserName);
     /** @brief encrypts or decrypt the data provided
      *
      *  @param[in] doEncrypt - do encrypt if set to true, else do decrypt.
@@ -81,11 +85,14 @@
      *  for the user specified.
      *
-     *  @param[in] userName - user name entry that has to be removed.
+     *  @param[in] userName - user name that has to be renamed / deleted
+     *  @param[in] newUserName - new user name. If empty, userName will be
+     *   deleted.
      *
      * @return error response